from django.apps import AppConfig


class DjangoAdminEnvBadgeConfig(AppConfig):
    default_auto_field = 'django.db.models.BigAutoField'
    name = "django_admin_env_badge"
    verbose_name = "Admin Environment Badge"